@@ -33,6 +33,7 @@
 #include "simutil.h"
 #include "util.h"
 #include "smsutil.h"
+#include "missing.h"
 
 struct sim_eons {
 	struct sim_eons_operator_info *pnn_list;
@@ -765,6 +766,20 @@ unsigned char *comprehension_tlv_builder_get_data(
 	return tlv + tag_size + len_size;
 }
 
+gboolean validate_utf8_tlv(const unsigned char *tlv)
+{
+	int len = tlv[1];
+
+	if (len == 0)
+		return FALSE;
+
+	/* support both null-terminated and non null-terminated TLV value */
+	if (tlv[len + 1] == '\0')
+		len -= 1;
+
+	return g_utf8_validate_len((const char *)tlv + 2, len, NULL);
+}
+
 static char *sim_network_name_parse(const unsigned char *buffer, int length,
 					gboolean *add_ci)
 {
@@ -1410,7 +1425,7 @@ gboolean sim_parse_3g_get_response(const unsigned char *data, int len,
 	if (tlv[1] != 0x21)
 		return FALSE;
 
-	switch (tlv[0] & 0x3) {
+	switch (tlv[0] & 0x7) {
 	case 1:	/* Transparent */
 		str = 0x00;
 		break;
@@ -1592,7 +1607,7 @@ GSList *sim_parse_app_template_entries(const unsigned char *buffer, int len)
 		} else
 			app.label = NULL;
 
-		ret = g_slist_prepend(ret, g_memdup(&app, sizeof(app)));
+		ret = g_slist_prepend(ret, g_memdup2(&app, sizeof(app)));
 
 		len -= (dataobj - buffer) + dataobj_len;
 		buffer = dataobj + dataobj_len;
@@ -1701,10 +1716,6 @@ gboolean sim_parse_umts_authenticate(const unsigned char *buffer,
 
 		break;
 	case 0xdc:
-		/* 'DC' + '0E' + AUTS(14) = 16 */
-		if (len < 16)
-			goto umts_end;
-
 		/* sync error */
 		if (buffer[1] != 0x0e)
 			goto umts_end;
